bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 35. Aventiure
___________________________________________________ #### Aventivre wie irinch #### erslagen wart
###### 2028 | ### Do rief von tenemarche | der margrave irinch ### ich han vf ere lazzen | nv lange miniv dinch ### vnde han in volches stvermen | des besten vil getan ### nv brinch mir min gewaeffen | ia wil ich hagenen bestan
###### 2029 | ### daz wil ich widerraten | sprach do hagene ### so heiz vf hoher wichen | der hivnen degene ### gespringent iwer zwene | oder dri in den sal ### di sende ich vil vngesvnde | di stiegen wider hin ce tal
###### 2030 | ### darvmbe ichz niht laze | sprach aber irinch ### ich han ovch e versvchet | sam sorchlichiv dinch ### ia wil ich mit dem swerte | dich einen bestan ### waz hilfet vebermveten | daz dv mit rede hast getan
###### 2031 | ### do wart gewaffent balde | der degen irinch ### vnde irnfrit von dveringen | ein chvener ivngelinch ### vnd hawart der vil starche | wol mit tvsent man ### swes irinch begvnde | si woldens alles im gestan
###### 2032 | ### do sah der videlaere | eine vil groze shar ### di mit iringe | gewaffent chomen dar ### si trvgen vf gebvnden | vil manegen helm gvt ### do wart der chvene volker | ein teil vil zornech gemvt
###### 2033 | ### seht ir vrivnt hagene | dort iringen gan ### der ivh mit dem swerte | lobt eine bestan ### wi zement helde lvgene | ich wil vnprisen daz ### ez gent mit im gewaffent | wol tvsent recken oder baz
###### 2034 | ### nv heiz et mich niht liegen | sprah hawartes man ### ich wilz gerne leisten | swaz ich gelobt han ### dvrh deheine vorhte | wil ich es ab gan ### swi grivlich si nv hagene | ich wil in eine bestan
###### 2035 | ### ze fvzen bot sich irinch | magen vnd man ### do in eine liezen | di recken bestan ### daz taten si vngerne | wand in was wol bechant ### der vebermvete hagene | vzer bvrgonden lant
###### 2036 | ### do bat er si so lange | daz ez sit geschach ### do daz ingesinde | den willen sin ersach ### daz er warp nach eren | do liezen si in gan ### do wart von in beiden | ein grimmez striten getan
###### 2037 | ### irinch von tenemarche | vil hohe trvch den ger ### sich dachte mit dem schilde | der tiwer degen her ### do lief er vf ce hagenen | vaste fver den sal ### do hvb sich von den degenen | ein vil grozlicher schal
###### 2038 | ### do shvzen si di gere | mit chrepfte von der hant ### dvrch di vesten shilde | vf liehtez ir gewant ### daz di gerstangen | vil hohe draeten dan ### do griffen zv den swerten | di zwene grimme chvene man
###### 2039 | ### des chvenen hagen ellen | daz was starche groz ### do slvch ovch vf in irinc | daz al daz hvs erdoz ### palas vnd tvrne | erhvllen nach ir slegen ### do ne chonde niht verenden | des sinen willen der degen
###### 2040 | ### irinch der lie hagenen | vnverwundet stan ### zv dem videlaere | gahen er began ### er wande er moehte in twingen | mit sinen herten slegen ### do chonde sich wol beshermen | volker der degen
###### 2041 | ### do slvch der videlaere | daz veber des schildes rant ### draete daz gespenge | von volkeres hant ### den liez er do beliben | ez was ein vebel man ### do lief er gventheren | von den bvrgonden an
###### 2042 | ### do was ir ietweder | ce strite starch genvch ### swaz gventher vnd irinch | vf einander slvch ### daz brahte niht von wunden | daz vliezende plvt ### daz behvte ir gewaeffen | daz was starch vnde gvt
###### 2043 | ### gventhern er lie beliben | vnd lief gernoten an ### daz fiwer vz den ringen | er howen im began ### do hete von bvrgonden | der starche gernot ### den chvenen iringen | erslagen naehelichen tot
###### 2044 | ### do spranch er von dem fversten | snel er was genvch ### der bvrgonden viere | der helt vil balde slvch ### des edeln ingesindes | von wormez vber rin ### do ne chvnde giselher | nimmer zorneger gesin
###### 2045 | ### got weiz her irinch | sprach giselher daz chint ### ir mvezet mir di gelten | di vor iv tot sint ### gelegen hi ce stvnde | do lief er in an ### er slvch den tenlender | daz er mvse da bestan
###### 2046 | ### er shoz vor sinen handen | nider in daz plvt ### daz si alle wolden waenen | daz der helt gvt ### ce strite nimmer mere | geslvch einen slach ### irinch doh ane wunden | hie vor giselhern lach
###### 2047 | ### von des swertes doze | vnde von des helmes chlanch ### waren sine witze | worden harte chranch ### daz sich der degen chvene | des lebens niht versan ### daz het mit sinen chrepften | der starche giselher getan
###### 2048 | ### do im begonde entwichen | von dem hovbte der doz ### den er e da dolte | von dem slage groz ### er dahte ich pin noch lebende | vnd ninder wunt ### nv ist mir allererst | daz ellen giselheres chvnt
###### 2049 | ### do hort er beidenthalben | di viande stan ### wisten si div maere | im waere noch mer getan ### ovch het er giselheren | da bi im vernomen ### er dahte wi er solde | von den vianden chomen
###### 2050 | ### wi rehte tobeliche | er vz dem plvot spranch ### siner snelheite | er mohte sagen danch ### do lief er vz dem hvse | da er aber hagen vant ### vnd slvch im slege grimme | mit siner ellenthafter hant
###### 2051 | ### do dahte hagen | dv mvst des todes wesen ### dich en vride der vbel tivel | dv ne chanst niht genesen ### doch wunte irinch hagenen | dvrch sinen helmhvt ### daz tet der helt mit waschen | daz was ein waffen also gvt
###### 2052 | ### do der herre hagene | der wunden enpfant ### do erwagt im vngefvge | daz swert an siner hant ### al da mvse im entwichen | der hawartes man ### hin nider vo den stiegen | hagen im volgen began
###### 2053 | ### irinch der vil chvene | den schilt veber swanch ### vnd waere div selbe stiege | drier stiegen lanch ### di wile liez in hagen | ni slahen einen slach ### hey waz roter vanchen | ob sinem hovbte gelach
###### 2054 | ### wider zv den sinen | chom irinch wol gesvnt ### do wurden disiv maere | criemhilde rehte chvnt ### waz er von tronege hagenen | mit sinem strite het getan ### des im div chveneginne | vil hohe danchen began
###### 2055 | ### nv lon dir got irinch | vil maere helt gvt ### dv hast mir wol getroestet | daz herce vnde ovch den mvt ### nv sihe ih rot von plvte | hagenen sin gewant ### criemhilt nam im selbe | den schilt vor liebe von der hant
###### 2056 | ### ir mvget im mazen danchen | so sprach hagene ### wold erz noch versvochen | daz zaeme degene ### chom er danne hinnen | so waere er chvener man ### div wunde frvmt ivch chleine | die ich von im enpfangen han
###### 2057 | ### daz ir von miner wunden | di ringe sehet rot ### daz hat mich erreizet | vf maniges mannes tot ### ich pin allererst erzvernet | als ein vnverzaget man ### mir hat der degen irinch | shaden chleinen noch getan
###### 2058 | ### do stvnt gegen dem winde | irinch von tenelant ### er chvlte sich in ringen | den helm er ab gebant ### do sprachen al di livte | sin ellen waere gvt ### des het der marchgrave | einen riche hohen mvt
###### 2059 | ### aber sprach do irinch | mine vrivnt wizet daz ### daz ir mich wafent schiere | ich wilz versvchen baz ### ob ich noch mvege betwingen | den vebermveten man ### sin schilt was verhowen | einen bezern er gewan
###### 2060 | ### vil schiere wart der recke | do gewaffent baz ### einen ger vil starchen | nam er dvrch den haz ### damit er aber wolde | hagenen dort bestan ### do warte im vientliche | der mortgrimmege man
###### 2061 | ### sin mohte niht erbiten | hagen der degen ### er lief im hin engegene | mit shvezen vnde mit slegen ### di stiegen vz an ein ende | sin zorn der was groz ### irinch siner sterche | do vil wenech genoz
###### 2062 | ### si slvgen dvrch di shilde | daz iz lovgen began ### von fiwerroten wunden | der hawartes man ### wart von hagen swerte | chrepftechlichen wunt ### dvrh schilt vnd dvrch di brvenne | des er wart nimmer mer gesvnt
###### 2063 | ### do der degen irinch | der wunden enpfant ### den schilt er baz do rvchte | veber div helm bant ### des schaden in dvhte der volle | den er da gewan ### sit tet im aber mer | des kvenech gvntheres man
###### 2064 | ### hagen vor sinen fvzen | einen ger ligen vant ### er shoz vf iringen | den helt von tenelant ### daz im von dem hovbte | div stange ragete dan ### im hete der recke hagene | den grimmen ende getan
###### 2065 | ### irinch mvst entwichen | zv den von tenelant ### e daz man do dem degene | den helm ab gebant ### man brach den ger von hovbte | do nahete im der tot ### daz weinten sine mage | des gie in waerliche not
###### 2066 | ### do chom div chveneginne | veber in gegan ### den starchen iringen | chlagen si began ### si weinte sine wunden | ez was ir grimme leit ### do sprach vor sinen magen | der recke chvene vnt gemeit
###### 2067 | ### lat di chlage beliben | vil herlich wip ### waz hilfet iwer weinen | ia mvz ich minen lip ### verliesen von den wunden | di ich enpfangen han ### der tot wil niht langer | iv vnd eceln dienen lan
###### 2068 | ### er sprach zv den dveringen | vnt ce den von tenelant ### di gabe sol enpfahen | iwer deheines hant ### von der chveneginne | ir liehtez golt vil rot ### vnde bestet ir hagenen | ir mvezet chiesen den tot
###### 2069 | ### sin varwe was erblichen | des todes zeichen trvch ### irinch der vil chvene | ez was in leit genvch ### genesen niht en chvnde | der hawartes man ### do mvst ez an ein striten | von dem von tenemarche gan
###### 2070 | ### irnfrit vnde hawart | sprvngen fver daz gadem ### wol mit tvsent helden | vil vngefvegen cradem ### hort man allenthalben | chrepftech vnde groz ### hey waz man scharpfer gere | zv den bvrgonden shoz
###### 2071 | ### irnfrit der chvene | lief an den spilman ### des er den schaden grozen | von siner hant gewan ### der edel videlaere | den lantgraven slvch ### dvrch einen helm vesten | ia was er grimme genvch
###### 2072 | ### do slvch der herre irnfrit | den chvenen spilman ### daz im mvsen brestn | div ringes gespan ### vnt daz sich beschvte | div brvenne fiwerrot ### doch vil der lantgrave | vor dem videlaere tot
###### 2073 | ### hawart vnde hagene | cesamne waren chomen ### er mohte wunder chiesen | ders hete war genomen ### div swert genote vielen | den helden an der hant ### hawart mvst ersterben | von dem vzer bvrgonden lant
###### 2074 | ### do di tenen vnde di dverengen | ir herren sahen tot ### do hvb sich vor dem hvse | ein vreislichiv not ### e si di tver gewunnen | mit ellenthafter hant ### des wart da verhowen | vil manech helm vnde rant
###### 2075 | ### wichet sprach do volker | vnde lat si her in gan ### ez ist svs vnverendet | des si da habent wan ### si mvezen drinne ersterben | in vil chvrcer zit ### si erarnent mit dem tode | daz in div chveneginne git
###### 2076 | ### do di vebermveten | chomen in den sal ### vil manegem wart daz hovbt | geneiget so ze tal ### daz er mvse ersterben | von ir swinden slegen ### wol streit der chvene gernot | sam tet ovch giselher der degen
###### 2077 | ### tvsent vnde viere | chomen in daz hvs ### von swerten sach man blicken | vil manegen swinden svs ### sit wurden doch di recken | alle drinne erslagen ### man mohte michel wunder | von den bvergonden sagen
###### 2078 | ### darnach wart ein stille | do der shal verdoz ### daz plvot allenthalben | dvrh div loecher vloz ### vnt da cen rigelsteinen | von den toten man ### daz heten di von rine | mit grozem ellen getan
###### 2079 | ### do sazen aber ruowen | di von bvergonden lant ### div waffen den schilden | leitens vz der hant ### do stvnt noch vor dem tvrne | der chvene spilman ### er warte ob iemen wolde | noch zv zin mit strite gan
###### 2080 | ### der kvenech chlagete sere | sam tet ovch sin wip ### megede vnd vrowen | di qvelten da den lip ### ich waene des daz hete | der tot vf si gesworn ### des wart noch vil der recken | von den gesten da verlorn

<<< Übersicht <<< vorige Seite nächste Seite >>>